@@ -1,8 +1,10 @@
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE FlexibleInstances #-}
+{-# LANGUAGE DeriveGeneric #-}
 
 module Database.Relational.Schema.MySQLInfo.TableConstraints where
 
+import GHC.Generics (Generic)
 import Database.Relational.Query.TH (defineTableTypesAndRecord)
 
 import Database.Relational.Schema.MySQLInfo.Config (config)
@@ -15,4 +17,4 @@ $(defineTableTypesAndRecord config
     , ("constraint_name"    , [t| String |])
     , ("constraint_type"    , [t| String |])
     ]
-    [''Show])
+    [''Show, ''Generic])
